==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/CustomScaleRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Container App container Custom scaling rule.
 * @property auth Authentication secrets for the custom scale rule.
 * @property metadata Metadata properties to describe custom scale rule.
 * @property type Type of the custom scale rule
 * eg: azure-servicebus, redis etc.
 */
public data class CustomScaleRuleArgs(
    public val auth: Output<List<ScaleRuleAuthArgs>>? = null,
    public val metadata: Output<Map<String, String>>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs =
        com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs.builder()
            .auth(auth?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomScaleRuleArgs].
 */
@PulumiTagMarker
public class CustomScaleRuleArgsBuilder internal constructor() {
    private var auth: Output<List<ScaleRuleAuthArgs>>? = null

    private var metadata: Output<Map<String, String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("aikffrjrrkofjpxa")
    public suspend fun auth(`value`: Output<List<ScaleRuleAuthArgs>>) {
        this.auth = value
    }

    @JvmName("pnxvuoljighaldwf")
    public suspend fun auth(vararg values: Output<ScaleRuleAuthArgs>) {
        this.auth = Output.all(values.asList())
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("salyylouhbymwbpy")
    public suspend fun auth(values: List<Output<ScaleRuleAuthArgs>>) {
        this.auth = Output.all(values)
    }

    /**
     * @param value Metadata properties to describe custom scale rule.
     */
    @JvmName("hwgkgvfxqekrpxhq")
    public suspend fun metadata(`value`: Output<Map<String, String>>) {
        this.metadata = value
    }

    /**
     * @param value Type of the custom scale rule
     * eg: azure-servicebus, redis etc.
     */
    @JvmName("ugxjpxuxkewxqjwu")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("womdcuvnkgirowxc")
    public suspend fun auth(`value`: List<ScaleRuleAuthArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("ebcswlqvayabohhq")
    public suspend fun auth(argument: List<suspend ScaleRuleAuthArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("udoedqwtyvjhnalq")
    public suspend fun auth(vararg argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("cvqnyaolqocgvpjd")
    public suspend fun auth(argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleAuthArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("lrrixcnytejetggr")
    public suspend fun auth(vararg values: ScaleRuleAuthArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param value Metadata properties to describe custom scale rule.
     */
    @JvmName("rdyuiieqjvamlynq")
    public suspend fun metadata(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param values Metadata properties to describe custom scale rule.
     */
    @JvmName("icnlkltsubojhfcy")
    public fun metadata(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param value Type of the custom scale rule
     * eg: azure-servicebus, redis etc.
     */
    @JvmName("rjlsrcakbsvyfiwf")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): CustomScaleRuleArgs = CustomScaleRuleArgs(
        auth = auth,
        metadata = metadata,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/CustomScaleRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Container App container Custom scaling rule.
 * @property auth Authentication secrets for the custom scale rule.
 * @property metadata Metadata properties to describe custom scale rule.
 * @property type Type of the custom scale rule
 * eg: azure-servicebus, redis etc.
 */
public data class CustomScaleRuleArgs(
    public val auth: Output<List<ScaleRuleAuthArgs>>? = null,
    public val metadata: Output<Map<String, String>>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs =
        com.pulumi.azurenative.web.inputs.CustomScaleRuleArgs.builder()
            .auth(auth?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomScaleRuleArgs].
 */
@PulumiTagMarker
public class CustomScaleRuleArgsBuilder internal constructor() {
    private var auth: Output<List<ScaleRuleAuthArgs>>? = null

    private var metadata: Output<Map<String, String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("rsocstqfvfmlyrai")
    public suspend fun auth(`value`: Output<List<ScaleRuleAuthArgs>>) {
        this.auth = value
    }

    @JvmName("jepqxcuuqfiqbhbe")
    public suspend fun auth(vararg values: Output<ScaleRuleAuthArgs>) {
        this.auth = Output.all(values.asList())
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("fgtwwvwgseykvwur")
    public suspend fun auth(values: List<Output<ScaleRuleAuthArgs>>) {
        this.auth = Output.all(values)
    }

    /**
     * @param value Metadata properties to describe custom scale rule.
     */
    @JvmName("lklhjnrhonjdpcyc")
    public suspend fun metadata(`value`: Output<Map<String, String>>) {
        this.metadata = value
    }

    /**
     * @param value Type of the custom scale rule
     * eg: azure-servicebus, redis etc.
     */
    @JvmName("cursrmaefbkkhpqn")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("qsxpaamqcdjanehy")
    public suspend fun auth(`value`: List<ScaleRuleAuthArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("tvmcuxvrckhedxus")
    public suspend fun auth(argument: List<suspend ScaleRuleAuthArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("ghtifvkroykfkqfj")
    public suspend fun auth(vararg argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("smkgqprjfogggokv")
    public suspend fun auth(argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleAuthArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("gnyndgbahmbocgmp")
    public suspend fun auth(vararg values: ScaleRuleAuthArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param value Metadata properties to describe custom scale rule.
     */
    @JvmName("lhengobbmeyqticg")
    public suspend fun metadata(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param values Metadata properties to describe custom scale rule.
     */
    @JvmName("drkepinitapvntmg")
    public fun metadata(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param value Type of the custom scale rule
     * eg: azure-servicebus, redis etc.
     */
    @JvmName("xsduwnfdoxvbwptn")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): CustomScaleRuleArgs = CustomScaleRuleArgs(
        auth = auth,
        metadata = metadata,
        type = type,
    )
}
